@@ -67,8 +67,8 @@ VideoControl::VideoControl()
 {
   SetDestroyOnCleanup(false);
 
-  AttachModel(gstMsg);
-  AttachModel(timer);
+  Observe(gstMsg);
+  Observe(timer);
 }
 
 VideoControl::~VideoControl()
@@ -169,7 +169,7 @@ void VideoControl::CalcSize()
   width=160;
   height=120;
 
-  AttachModel(dynamic_cast<Lum::Dialog*>(GetWindow()->GetMaster())->GetOpenedAction());
+  Observe(dynamic_cast<Lum::Dialog*>(GetWindow()->GetMaster())->GetOpenedAction());
 
   minWidth=width;
   minHeight=height;
